@@ -16,7 +16,7 @@ from ikabot.helpers.pedirInfo import read
 from ikabot.helpers.planRoutes import waitForArrival
 from ikabot.helpers.process import set_child_mode
 from ikabot.helpers.signals import setInfoSignal
-from ikabot.helpers.varios import addThousandSeparator, wait
+from ikabot.helpers.varios import addThousandSeparator, wait, getDateTime
 from ikabot.helpers.pedirInfo import getShipCapacity
 
 
@@ -177,7 +177,6 @@ def sellToOffers(session, city_to_buy_from, resource_type, event):
     for offer in chosen_offers:
         cityname, username, amount, price, dist, destination_city_id = offer
         cityname = cityname.strip()
-        amount = amount.replace(",", "").replace(".", "")
         amount = int(amount)
         price = int(price)
         sell = min(amount, left_to_sell)
@@ -347,8 +346,7 @@ def do_it1(session, left_to_sell, offers, resource_type, city_to_buy_from):
     for offer in offers:
         cityname, username, amount, precio, dist, destination_city_id = offer
         cityname = cityname.strip()
-        amount_to_buy = amount.replace(",", "").replace(".", "")
-        amount_to_buy = int(amount_to_buy)
+        amount_to_buy = int(amount)
         while True:
             amount_to_sell = min(amount_to_buy, left_to_sell)
             ships_available = waitForArrival(session)
@@ -393,6 +391,11 @@ def do_it1(session, left_to_sell, offers, resource_type, city_to_buy_from):
 
             session.get(city_url + city_to_buy_from["id"], noIndex=True)
             session.post(params=data)
+            
+            resource_name = materials_names[resource_type]
+            session.setStatus(
+                f"Sold {addThousandSeparator(amount_to_sell)} {resource_name} for {precio} gold to {cityname} ({username}) <--- {city_to_buy_from['name']} | {getDateTime()}"
+            )
 
             if left_to_sell == 0:
                 return
